/*
 * COPYRIGHT © 2017 YOSPACE TECHNOLOGIES LTD. ALL RIGHTS RESERVED.
 */

#import <Foundation/Foundation.h>
#import "YSDebugFlags.h"


/** The YSSessionProperties class is used to provide custom properties to the Session Manager at initialisation.
 
 */
@interface YSSessionProperties : NSObject <NSCopying>

/**
 Defines the receiver's timeout interval for HTTP requests for session initialisation and CSM polling.<br/>
 If during a connection attempt the request remains idle for longer than this value, the request is considered to have timed out.<br/>
 The default value is 15 seconds.
 */
@property (nonatomic) NSTimeInterval timeout;

/**
 If present, defines a failover Url to be used in the case that the Central Streaming Manager cannot be contacted with the first Url. This Url may or may not be a CSM Url.
 */
@property (nonatomic, copy) NSURL* failoverURL;

/**
 If not nil or empty, contains one or more NSString objects, interpreted as regular expressions, used to evaluate whether a primary or secondary URL is in fact a masked reference to a CSM stream. If a primary or secondary URL matches any of the patterns provided the URL will be used to attempt to establish a CSM session. These patterns enable the use of HTTP redirects to mask CSM URLs behind other arbitrary URLs. The patterns are applied in addition to standard CSM URL identification. As a consequence no particular patterns need be applied if redirections are not in use.
 */
@property (nonatomic, copy) NSArray* csmPatterns;

/**
 If not nil or empty, contains one or more NSString objects, interpreted as regular expressions, used to determine whether a string that defines a URL in a received VAST document should be ignored. If the string is matched then the  corresponding event, clickthrough or resource will not be created for the corresponding advert.
 */
@property (nonatomic, copy) NSArray* vastUrlIgnorePatterns;

/**
 Defines whether the URL passed into the SDK is known to redirect to a CSM URL. If true, the SDK obtains the actual redirect URL from the Location header in the 302 response and uses that to initialise. Note that the SDK will still inspect any custom CSM pattern regex expressions that may be passed in.
 */
@property (nonatomic) BOOL isRedirectURL;

/**
 Defines whether the initialisation process should use a proxy object, which intercepts the master playlist to retrieve Yospace session information. If this property is `NO` then the Session Manager makes an additional specific call to the CSM to retrieve this information.
 */
@property (nonatomic) BOOL useProxy;

/**
 Defines whether the SDK will poll for VAST over HTTP Secure regardless of the scheme used in the playback URL.
 */
@property (nonatomic) BOOL forceHttpsPolling;

/**
 If present, defines the HTTP user-agent to be used by the Session Manager when firing remote analytics tracking events.
 */
@property (nonatomic, copy) NSString* analyticsUserAgent;

/**
 If present, defines the HTTP user-agent to be used by the Session Manager when initiating a redirect request as part of initialisation.
 */
@property (nonatomic, copy) NSString* redirectUserAgent;

/**
 Defines the segment length (playlist `target duration`) for adverts in a stream. This is usually the same as the stream.
 This value must be set in order for analytics to function properly when using filler in advert breaks.
 The default value is 11 seconds.
 */
@property (nonatomic) NSInteger targetDuration;

/**
 Defines a set of debug flags that control aspects of logging output.<br/>
 The SDK is initialised with a 'sensible' default set, which can be overridden by calling this method.<br/>
 New values must by OR'ed together e.g. ```[props setDebugFlags:DEBUG_PARSING | DEBUG_VAST_POLLING];```
 
 @param value OR'ed combination of debug flags
 */
+(void) setDebugFlags:(YSEDebugFlags)value;

/**
 Defines a set of debug flags, in addition to the default set, that control aspects of logging output.<br/>
 The SDK is initialised with a 'sensible' default set, which can augmented by calling this method.<br/>
 New values must by OR'ed together e.g. ```[props addDebugFlags:DEBUG_PARSING | DEBUG_VAST_POLLING];```
 
 @param value OR'ed combination of debug flags
 */
+(void) addDebugFlags:(YSEDebugFlags)value;

@end
